Summary:         Utilities for mounting and managing CIFS mounts
Name:            cifs-utils
Version:         7.0
Release:         1%{?dist}
License:         GPLv3
URL:             http://linux-cifs.samba.org/cifs-utils/
Source0:         https://download.samba.org/pub/linux-cifs/cifs-utils/%{name}-%{version}.tar.bz2

BuildRequires:  gcc make automake autoconf
BuildRequires:  libcap-ng-devel libtalloc-devel krb5-devel keyutils-libs-devel pam-devel
BuildRequires:  python3-docutils libwbclient-devel

Requires:        keyutils
Requires(post):  /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives

Recommends: %{name}-info = %{version}-%{release}

%description
The in-kernel CIFS filesystem is generally the preferred method for
mounting SMB/CIFS shares on Linux.
The in-kernel CIFS filesystem relies on a set of user-space tools.
That package of tools is called cifs-utils. Although not really part
of Samba proper, these tools were originally part of the Samba package.
For several reasons, shipping these tools as part of Samba was problematic
and it was deemed better to split them off into their own package.

%package devel
Summary:        Files needed for building plugins for cifs-utils

%description devel
This package provides the header file for building ID mapping plugins for cifs-utils.

%package -n pam_cifscreds
Summary:        PAM module to manage NTLM credentials in kernel keyring

%description -n pam_cifscreds
The package provides a tool for automatically adding credentials
(username and password) for the purpose of establishing sessions
in multiuser mounts.

%package info
Summary: Additional tools for querying information about CIFS mount
Requires: %{name} = %{version}-%{release}

%description info
This package provides tools for querying information about CIFS mount.

%prep
%autosetup -p1 %{name}-%{version}

%build
fgrep -r -l '/usr/bin/env python' | xargs -n1 sed -i 's@/usr/bin/env python.*@%python3@g'
autoreconf -i
%configure --prefix=/usr ROOTSBINDIR=%{_sbindir}
%make_build



%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/request-key.d
install -m644 contrib/request-key.d/cifs.idmap.conf %{buildroot}%{_sysconfdir}/request-key.d
install -m644 contrib/request-key.d/cifs.spnego.conf %{buildroot}%{_sysconfdir}/request-key.d

%post
/usr/sbin/alternatives --install /etc/cifs-utils/idmap-plugin cifs-idmap-plugin %{_libdir}/%{name}/idmapwb.so 10

%preun
if [ $1 = 0 ]; then
    /usr/sbin/alternatives --remove cifs-idmap-plugin %{_libdir}/%{name}/idmapwb.so
fi

%files
%license COPYING
%{_bindir}/cifscreds
%{_bindir}/getcifsacl
%{_bindir}/setcifsacl
%{_sbindir}/mount.cifs
%{_sbindir}/mount.smb3
%{_sbindir}/cifs.upcall
%{_sbindir}/cifs.idmap
%{_libdir}/%{name}/idmapwb.so
%dir %{_sysconfdir}/cifs-utils
%ghost %{_sysconfdir}/cifs-utils/idmap-plugin
%config(noreplace) %{_sysconfdir}/request-key.d/cifs.idmap.conf
%config(noreplace) %{_sysconfdir}/request-key.d/cifs.spnego.conf
%{_mandir}/man1/cifscreds.*
%{_mandir}/man1/getcifsacl.*
%{_mandir}/man1/setcifsacl.*
%{_mandir}/man8/cifs.upcall.*
%{_mandir}/man8/cifs.idmap.*
%{_mandir}/man8/mount.cifs.*
%{_mandir}/man8/mount.smb3.*
%{_mandir}/man8/idmapwb.*

%files devel
%{_includedir}/cifsidmap.h

%files -n pam_cifscreds
%{_libdir}/security/pam_cifscreds.so
%{_mandir}/man8/pam_cifscreds.8.gz

%files info
%{_bindir}/smb2-quota
%{_bindir}/smbinfo
%{_mandir}/man1/smb2-quota.*
%{_mandir}/man1/smbinfo.*

%changelog
* Mon Jun 26 2023 kianli <kianli@tencent.com> - 7.0-1
- Upgrade to 7.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.13-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.13-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Feb 24 2023 cunshunxia <cunshunxia@tencent.com> - 6.13-2
- fix postun script bug.

* Mon Nov 21 2022 cunshunxia <cunshunxia@tencent.com> - 6.13-1
- initial build
